==> gnote-0.8.0.tar.xz: gnote-0.8.0/src/prefskeybinder.hpp <==
/*
 * gnote
 *
 * Copyright (C) 2011 Aurimas Cernius
 * Copyright (C) 2009 Hubert Figuiere
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */



#ifndef _PREFSKEYBINDER_HPP_
#define _PREFSKEYBINDER_HPP_

#include <string>
#include <sigc++/signal.h>
#include <sigc++/slot.h>

#include "preferences.hpp"

namespace gnote {

class TrayIcon;
class NoteManager;
class IGnoteTray;
class IKeybinder;


class PrefsKeybinder : public sigc::trackable
{
public:
  PrefsKeybinder();
  virtual ~PrefsKeybinder();
  void bind(const std::string & pref_path, const std::string & default_binding, 
            const sigc::slot<void> & handler);
  void unbind_all();

private:
  class Binding;

  IKeybinder & m_native_keybinder;
  std::list<Binding*> m_bindings;
};

class GnotePrefsKeybinder
  : public PrefsKeybinder
{
public:
  GnotePrefsKeybinder(NoteManager & manager, IGnoteTray & trayicon);
  void enable_keybindings_changed(const Glib::ustring & key);
  void enable_disable(bool enable);
private:
  void key_show_menu();
  void key_openstart_here();
  void key_create_new_note();
  void key_open_search();
  void key_open_recent_changes();
  NoteManager & m_manager;
  IGnoteTray & m_trayicon;
};


}

#endif

==> gnote_3.10.3.orig.tar.xz: gnote-3.10.3/src/prefskeybinder.hpp <==
/*
 * gnote
 *
 * Copyright (C) 2011,2013 Aurimas Cernius
 * Copyright (C) 2009 Hubert Figuiere
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */



#ifndef _PREFSKEYBINDER_HPP_
#define _PREFSKEYBINDER_HPP_

#include <string>
#include <sigc++/signal.h>
#include <sigc++/slot.h>

#include "preferences.hpp"

namespace gnote {

class TrayIcon;
class NoteManager;
class IGnoteTray;
class IKeybinder;


class PrefsKeybinder : public sigc::trackable
{
public:
  PrefsKeybinder(IKeybinder &);
  virtual ~PrefsKeybinder();
  void bind(const std::string & pref_path, const std::string & default_binding, 
            const sigc::slot<void> & handler);
  void unbind_all();

private:
  class Binding;

  IKeybinder & m_native_keybinder;
  std::list<Binding*> m_bindings;
};

class GnotePrefsKeybinder
  : public PrefsKeybinder
{
public:
  GnotePrefsKeybinder(IKeybinder & keybinder, NoteManager & manager, IGnoteTray & trayicon);
  void enable_keybindings_changed(const Glib::ustring & key);
  void enable_disable(bool enable);
private:
  void key_show_menu();
  void key_openstart_here();
  void key_create_new_note();
  void key_open_search();
  void key_open_recent_changes();
  NoteManager & m_manager;
  IGnoteTray & m_trayicon;
};


}

#endif
